import 'package:flutter/material.dart';

enum AnimationType {
  normal,
  fadeIn,
}

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType? animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions({
    required this.context,
    required this.child,
    this.animation = AnimationType.normal,
    this.duration = const Duration(milliseconds: 300),
    this.replacement = false,
  }) {
    switch (this.animation!) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
    }
  }

  void _normalTransition() {
    (replacement)
        ? Navigator.pushReplacement(
            context, MaterialPageRoute(builder: (_) => this.child))
        : Navigator.push(
            context, MaterialPageRoute(builder: (_) => this.child));
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
      pageBuilder: (_, __, ___) => child,
      transitionDuration: duration,
      transitionsBuilder: (_, animation, __, ___) {
        return FadeTransition(
          child: child,
          opacity: Tween<double>(begin: 0.0, end: 1.0).animate(CurvedAnimation(
            parent: animation,
            curve: Curves.easeInOut,
          )),
        );
      },
    );

    (replacement)
        ? Navigator.pushReplacement(context, route)
        : Navigator.push(context, route);
  }
}
